netapp_ontap.models.recent_workspaces_inner API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.recent_workspaces_inner`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class RecentWorkspacesInnerSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the RecentWorkspacesInner object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `data_collection_count: Size GET POST PATCH`

    Number of data collections in the workspace.

    Example: 3

  `entity_count: Size GET POST PATCH`

    Number of entities in the workspace.

    Example: 1000

  `name: str GET POST PATCH`

    Name of the workspace.

    Example: Finance

  `scanned_size: Size GET POST PATCH`

    Scanned size of the workspace.

    Example: 7663353

  `sensitive_entity_count: Size GET POST PATCH`

    Number of sensitive entities in the workspace.

    Example: 10

  `uuid: str GET POST PATCH`

    UUID of the workspace.

    Example: 02c9e252-41be-11e9-81d5-00a0986138f7